==> youtubeplugin-0.0.3.tar.gz: android/src/main/java/com/usk/youtubeplugin/YoutubePlugin.java <==
package com.usk.youtubeplugin;

import android.app.Activity;
import android.content.Intent;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * YoutubepluginPlugin
 */
public class YoutubePlugin implements FlutterPlugin, MethodCallHandler,  EventChannel.StreamHandler {

    private MethodChannel channel;
    Activity activity;
    static EventChannel.EventSink events;
    private static final String STREAM_CHANNEL_NAME = "USKAPP/flutter_youtube_stream";
    private static final int YOUTUBE_PLAYER_RESULT = 6646;
    private static final String METHOD_CHANNEL = "USKAPP/flutter_youtube";

    public YoutubePlugin() {

    }

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), METHOD_CHANNEL);
        channel.setMethodCallHandler(this);
    }


    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {
        YoutubePlugin plugin = new YoutubePlugin();
        plugin.setActivity(registrar.activity());

        final MethodChannel channel = new MethodChannel(registrar.messenger(), METHOD_CHANNEL);
        channel.setMethodCallHandler(plugin);
        registrar.addActivityResultListener(new PluginRegistry.ActivityResultListener() {
            @Override
            public boolean onActivityResult(int i, int i1, Intent intent) {
                if (i == YOUTUBE_PLAYER_RESULT) {
                    if (intent != null) {
                        if (intent.getIntExtra("done", -1) == 0) {
                            if (events != null) {
                                events.success("done");
                            }
                        }
                    }
                }
                return false;
            }
        });

        final EventChannel eventChannel = new EventChannel(registrar.messenger(), STREAM_CHANNEL_NAME);
        YoutubePlugin youtubeWithEventChannel = new YoutubePlugin();
        youtubeWithEventChannel.setActivity(registrar.activity());
        eventChannel.setStreamHandler(youtubeWithEventChannel);
    }

    private void setActivity(Activity activity) {
        this.activity  = activity;
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

          if (call.method.equals("playYoutubeVideo")) {

            String videoId = call.argument("id");
            boolean autoPlay = call.argument("autoPlay");
            boolean fullScreen = call.argument("fullScreen");
            boolean appBarVisible = call.argument("appBarVisible");
            Long appBarColor = call.argument("appBarColor");
            Long backgroundColor = call.argument("backgroundColor");


            Intent playerIntent = new Intent(activity, PlayerActivity.class);

            playerIntent.putExtra("videoId", videoId);
            playerIntent.putExtra("autoPlay", autoPlay);
            playerIntent.putExtra("fullScreen", fullScreen);
            playerIntent.putExtra("appBarVisible", appBarVisible);
            playerIntent.putExtra("appBarColor", appBarColor.intValue());
            playerIntent.putExtra("backgroundColor", backgroundColor.intValue());

            activity.startActivityForResult(playerIntent, YOUTUBE_PLAYER_RESULT);
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    private void handleMethod(MethodCall call, Result result){
      if (call.method.equals("playYoutubeVideo")) {

        String videoId = call.argument("id");
        boolean autoPlay = call.argument("autoPlay");
        boolean fullScreen = call.argument("fullScreen");
        boolean appBarVisible = call.argument("appBarVisible");
        Long appBarColor = call.argument("appBarColor");
        Long backgroundColor = call.argument("backgroundColor");


        Intent playerIntent = new Intent(activity, PlayerActivity.class);

        playerIntent.putExtra("videoId", videoId);
        playerIntent.putExtra("autoPlay", autoPlay);
        playerIntent.putExtra("fullScreen", fullScreen);
        playerIntent.putExtra("appBarVisible", appBarVisible);
        playerIntent.putExtra("appBarColor", appBarColor.intValue());
        playerIntent.putExtra("backgroundColor", backgroundColor.intValue());

        activity.startActivityForResult(playerIntent, YOUTUBE_PLAYER_RESULT);

      } else {
        result.notImplemented();
      }
    }

    @Override
    public void onListen(Object o, EventChannel.EventSink eventSink) {
        events = eventSink;
    }

    @Override
    public void onCancel(Object o) {
        events = null;
    }
}

==> youtubeplugin-0.0.6.tar.gz: android/src/main/java/com/usk/youtubeplugin/YoutubePlugin.java <==
package com.usk.youtubeplugin;

import android.app.Activity;
import android.content.Intent;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * YoutubepluginPlugin
 */
public class YoutubePlugin implements FlutterPlugin, MethodCallHandler,  EventChannel.StreamHandler, ActivityAware, PluginRegistry.NewIntentListener {

    private MethodChannel channel;
    Activity activity;
    static EventChannel.EventSink events;
    private static final String STREAM_CHANNEL_NAME = "USKAPP/flutter_youtube_stream";
    private static final int YOUTUBE_PLAYER_RESULT = 6646;
    private static final String METHOD_CHANNEL = "USKAPP/flutter_youtube";

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), METHOD_CHANNEL);
        channel.setMethodCallHandler(this);
    }


    // This static function is optional and equivalent to onAttachedToEngine. It supports the old
    // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
    // plugin registration via this function while apps migrate to use the new Android APIs
    // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
    //
    // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
    // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
    // depending on the user's project. onAttachedToEngine or registerWith must both be defined
    // in the same class.
    public static void registerWith(Registrar registrar) {
        YoutubePlugin plugin = new YoutubePlugin();
        plugin.setActivity(registrar.activity());

        final MethodChannel channel = new MethodChannel(registrar.messenger(), METHOD_CHANNEL);
        channel.setMethodCallHandler(plugin);
        registrar.addActivityResultListener(new PluginRegistry.ActivityResultListener() {
            @Override
            public boolean onActivityResult(int i, int i1, Intent intent) {
                if (i == YOUTUBE_PLAYER_RESULT) {
                    if (intent != null) {
                        if (intent.getIntExtra("done", -1) == 0) {
                            if (events != null) {
                                events.success("done");
                            }
                        }
                    }
                }
                return false;
            }
        });

        final EventChannel eventChannel = new EventChannel(registrar.messenger(), STREAM_CHANNEL_NAME);
        YoutubePlugin youtubeWithEventChannel = new YoutubePlugin();
        youtubeWithEventChannel.setActivity(registrar.activity());
        eventChannel.setStreamHandler(youtubeWithEventChannel);
    }

    private void setActivity(Activity activity) {
        this.activity  = activity;
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

          if (call.method.equals("playYoutubeVideo")) {

            String videoId = call.argument("id");
            boolean autoPlay = call.argument("autoPlay");
            boolean fullScreen = call.argument("fullScreen");
            boolean appBarVisible = call.argument("appBarVisible");
            Long appBarColor = call.argument("appBarColor");
            Long backgroundColor = call.argument("backgroundColor");


            Intent playerIntent = new Intent(activity, PlayerActivity.class);

            playerIntent.putExtra("videoId", videoId);
            playerIntent.putExtra("autoPlay", autoPlay);
            playerIntent.putExtra("fullScreen", fullScreen);
            playerIntent.putExtra("appBarVisible", appBarVisible);
            playerIntent.putExtra("appBarColor", appBarColor.intValue());
            playerIntent.putExtra("backgroundColor", backgroundColor.intValue());

            activity.startActivityForResult(playerIntent, YOUTUBE_PLAYER_RESULT);
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    private void handleMethod(MethodCall call, Result result){
      if (call.method.equals("playYoutubeVideo")) {

        String videoId = call.argument("id");
        boolean autoPlay = call.argument("autoPlay");
        boolean fullScreen = call.argument("fullScreen");
        boolean appBarVisible = call.argument("appBarVisible");
        Long appBarColor = call.argument("appBarColor");
        Long backgroundColor = call.argument("backgroundColor");


        Intent playerIntent = new Intent(activity, PlayerActivity.class);

        playerIntent.putExtra("videoId", videoId);
        playerIntent.putExtra("autoPlay", autoPlay);
        playerIntent.putExtra("fullScreen", fullScreen);
        playerIntent.putExtra("appBarVisible", appBarVisible);
        playerIntent.putExtra("appBarColor", appBarColor.intValue());
        playerIntent.putExtra("backgroundColor", backgroundColor.intValue());

        activity.startActivityForResult(playerIntent, YOUTUBE_PLAYER_RESULT);

      } else {
        result.notImplemented();
      }
    }

    @Override
    public void onListen(Object o, EventChannel.EventSink eventSink) {
        events = eventSink;
    }

    @Override
    public void onCancel(Object o) {
        events = null;
    }

    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding activityPluginBinding) {
        activityPluginBinding.addOnNewIntentListener(this);
        this.activity = activityPluginBinding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        this.activity = null;
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding activityPluginBinding) {
        activityPluginBinding.addOnNewIntentListener(this);
        this.activity = activityPluginBinding.getActivity();
    }

    @Override
    public void onDetachedFromActivity() {
        this.activity = null;
    }

    @Override
    public boolean onNewIntent(Intent intent) {
        return false;
    }
}
